---
name: "How to do something❓"
about: How to do something using fastreid? What does an API do?

---

## ❓ How to do something using fastreid

Describe what you want to do, including:

1. what inputs you will provide, if any:
2. what outputs you are expecting:

NOTE:

1. Only general answers are provided.
   If you want to ask about "why X did not work", please use the
   [Unexpected behaviors](https://github.com/JDAI-CV/fast-reid/issues/new/choose) issue template.

2. About how to implement new models / new dataloader / new training logic, etc., check documentation first.

3. We do not answer general machine learning / computer vision questions that are not specific to fastreid, such as how a model works, how to improve your training/make it converge, or what algorithm/methods can be used to achieve X.
